@@ -141,6 +141,7 @@ class PlaywrightBrowserExecutor:
         attempt = 0
         last_error: Optional[Exception] = None
         task_id: Optional[str] = "unknown"
+        result: Any = None
 
         while attempt <= self.retries:
             page = None
@@ -161,6 +162,27 @@ class PlaywrightBrowserExecutor:
                     error=last_error,
                     result=result
                 )
+            except (asyncio.CancelledError, KeyboardInterrupt):
+                # ⚠️ 不要当成错误
+                self.logger.warning(f"[Task<{task_id}> Cancelled]")
+
+                # 清理资源
+                if context:
+                    await self._cleanup_context(context)
+                    if self.record_trace:
+                        os.makedirs(self.trace_dir, exist_ok=True)
+                        trace_path = os.path.join(self.trace_dir, f"{task_id}.zip")
+                        await context.tracing.stop(path=trace_path)
+                        self.logger.error(f"[Trace Saved] {trace_path}")
+
+                # ❗关键：不要 raise
+                return RunResult(
+                    success=False,
+                    attempts=attempt,
+                    error=asyncio.CancelledError(),
+                    task_id=task_id,
+                    result=result
+                )
             except Exception as e:
                 last_error = e
                 self.logger.error(f"[Task<{task_id}> Attempt {attempt} Failed] {e}")
@@ -187,5 +209,5 @@ class PlaywrightBrowserExecutor:
             attempts=attempt,
             error=last_error,
             task_id=task_id,
-            result=None
+            result=result
         )
